package main.controller;

import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CookieValue;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import main.config.OauthConfig;
import main.oauth.OauthProcessorImpl;

@RestController
public class OauthController {
	private static final Logger logger = LoggerFactory.getLogger(OauthController.class);

	@Autowired
	private OauthProcessorImpl oauthProcessor;
	
	
	@Autowired
	OauthConfig oauthConfig;
	
	//标准oauth
	@RequestMapping(value = "/main/oauth/callback", method = RequestMethod.GET)
	public void oauthcallback(@RequestParam(name = "code") String code,@RequestParam(name = "sessionId") String sessionId, @RequestParam(name = "location") String location) throws Exception {
		oauthProcessor.process(code, location);
	}
	
	
	
	//判断注销
	@RequestMapping(value = "/main/oauth/access", method = RequestMethod.GET)
	public void oauthAccess(@RequestParam(name = "location") String location,
			@CookieValue(value="nd_sso_portal_info",required= false) String ndSsoPortalInfo,
			@RequestHeader(value="X-Credential-Username", required=false) String userName,
			HttpServletResponse response
			) throws Exception {
		
		boolean needSsoLogin = false;
		if(StringUtils.isEmpty(ndSsoPortalInfo) || StringUtils.isEmpty(userName)) {
			needSsoLogin = true;
		}else {
			String[] ssoInfo = ndSsoPortalInfo.split("@sso@");
			String ssoSessionValue = oauthProcessor.getSsoCookie(ssoInfo[0]);
			if(StringUtils.isNotEmpty(ssoInfo[1]) && StringUtils.equals(ssoSessionValue, ssoInfo[1])) {
				needSsoLogin = false;
			}
		}
		
		if(needSsoLogin) {
			response.addHeader("location",oauthConfig.getOauthCallbackUrl(location));
			response.setStatus(302);
		}else {
			if(!oauthProcessor.checkPermission()) {
				throw new RuntimeException("访问页面权限不足");
			}
			response.addHeader("location", location);
			response.setStatus(302);
		}
	}
	
	
}
